@@ -14,11 +14,13 @@ package filter
 
 import (
 	"errors"
+	"fmt"
+	"os"
+
 	"github.com/eclipse/che-machine-exec/api/model"
-	"k8s.io/api/core/v1"
+	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	corev1 "k8s.io/client-go/kubernetes/typed/core/v1"
-	"os"
 )
 
 const (
@@ -49,14 +51,14 @@ func NewKubernetesContainerFilter(namespace string, podGetterApi corev1.PodsGett
 func (filter *KubernetesContainerFilter) GetContainerList() (containersInfo []*model.ContainerInfo, err error) {
 	pods, err := filter.getWorkspacePods()
 	if err != nil {
-		return containersInfo, err
+		return nil, err
 	}
 
 	for _, pod := range pods.Items {
 		for _, container := range pod.Spec.Containers {
 			for _, env := range container.Env {
 				if env.Name == MachineNameEnvVar {
-					containersInfo = append(containersInfo, &model.ContainerInfo{ContainerName: env.Value, PodName: pod.Name})
+					containersInfo = append(containersInfo, &model.ContainerInfo{ContainerName: container.Name, PodName: pod.Name})
 				}
 			}
 		}
@@ -65,6 +67,23 @@ func (filter *KubernetesContainerFilter) GetContainerList() (containersInfo []*m
 	return containersInfo, nil
 }
 
+func (filter *KubernetesContainerFilter) GetContainer(name string) (containerInfo *model.ContainerInfo, err error) {
+	pods, err := filter.getWorkspacePods()
+	if err != nil {
+		return nil, err
+	}
+
+	for _, pod := range pods.Items {
+		for _, container := range pod.Spec.Containers {
+			if container.Name == name {
+				return &model.ContainerInfo{ContainerName: container.Name, PodName: pod.Name}, nil
+			}
+		}
+	}
+
+	return nil, errors.New(fmt.Sprintf("Workspace-related pod does not have container with name %s", name))
+}
+
 // Find container information by pod label: "wsId" and container environment variables "machineName".
 func (filter *KubernetesContainerFilter) FindContainerInfo(identifier *model.MachineIdentifier) (containerInfo *model.ContainerInfo, err error) {
 	wsPods, err := filter.getWorkspacePods()
@@ -88,7 +107,7 @@ func (filter *KubernetesContainerFilter) getWorkspacePods() (*v1.PodList, error)
 		return nil, errors.New("unable to get current workspace id")
 	}
 
-	filterOptions := metav1.ListOptions{LabelSelector: WsIdLabel + "=" + workspaceID}
+	filterOptions := metav1.ListOptions{LabelSelector: WsIdLabel + "=" + workspaceID, FieldSelector: "status.phase=Running"}
 	wsPods, err := filter.podGetterApi.Pods(filter.namespace).List(filterOptions)
 	if err != nil {
 		return nil, err
